/*
 ****************************************************************************
 *	Copyright 2011 SMSC. All rights reserved.
 *	UFXUtility.lib, Version-0.9.3
 *
 *	UFXUtilFunctions.h
 *  This file lists details of functions/APIs exposed by the library, and
 *  describes the details of Error codes.
 ****************************************************************************
 *
 *	UFX Library provides  APIs to program the EEPROM and to verify the DDR2
 *  Memory connectivity. These APIs implementations are exposed by a library and called from 
 *  the test application. The EEPROM programming and Memory verificaiton APIs 
 *  are listed below.
 *       - EEPROM Programming and verification functions:
 *             - UFXLIB_RESULT UFXLIB_API UFXCalcEepromSize(DWORD *pdwSize );
 *             - UFXLIB_RESULT UFXLIB_API UFXLibWriteEEprom(UCHAR *pucBuf, DWORD dStartAdd, DWORD dLen);
 *			   - UFXLIB_RESULT UFXLIB_API UFXLibReadEeprom(UCHAR *pucBuf, DWORD dStartAdd, DWORD dLen);
 *             - UFXLIB_RESULT UFXLIB_API UFXLibEraseEeprom();
 *		 - Memory Testing
 *          - Memory Init functions
 *             - UFXLIB_RESULT UFXLIB_API UFXSetMemSize(DWORD dwSize);
 *             - UFXLIB_RESULT UFXLIB_API UFXSetODTnFrequency(stMemoryParams stMemObj );
 *             - DWORD UFXLIB_API UFXGetMemSize();
 *             - UFXLIB_RESULT UFXLIB_API UFXGetODTnFrequency(stMemoryParams *pstMemObj );
 *          - Memory Test Functions
 *             - stMemStatus UFXLIB_API UFXMemoryDataLinesTest();
 *             - stMemStatus UFXLIB_API UFXMemoryAddressLinesTest();
 *             - stMemStatus UFXLIB_API UFXVerifyFullDRAM();
 *             - UFXLIB_RESULT UFXLIB_API UFXDRAMWrite(UCHAR *pucBuf, DWORD dStartAdd, DWORD dwLen, UCHAR ucTransferType );
 *             - UFXLIB_RESULT UFXLIB_API UFXDRAMRead(UCHAR *pucBuf, DWORD dStartAdd, DWORD dwLen );
 *		 - Image/Rectangle draw testing
 *			   - UFXLIB_RESULT UFXLIB_API UFXInitGE(stResolution_t stRes )
 *			   - UFXLIB_RESULT UFXLIB_API UFXDrawPic(UCHAR *ucPath)
 *			   - UFXLIB_RESULT UFXLIB_API UFXDrawRect(UFXLIB_RECT_COLOR eColor, stRect_t Rect)
 *			   - UFXLIB_RESULT UFXLIB_API UFXPreferedResolution(stResolution_t *)
 *		 - HDMI Sound testing
 *			   - UFXLIB_RESULT UFXLIB_API UFXHdmiPhyEnable(HDMI_SW_CFG_DATA *pHDMI_SW_CFG_DATAObj)
 *			   - UFXLIB_RESULT UFXLIB_API UFXHdmiPhyDisable()
 *
 *	Note: Every funtion exposed by this library is blocking and take its own 
 *	execution time. In header of every function timing details are provided
 *	These timings are appoximate timings and which can vary dependingon host
 *  machine capability and UFX system clock speed.
 *
 */
#include "windows.h"

#ifdef UFXLIB_EXPORTS
#define UFXLIB_API __declspec(dllexport)
#else
#define UFXLIB_API __declspec(dllimport)
#endif

#define ADVANCE_DISPLAY_API

/* Differen status codes returned by library */
typedef enum {
 UFX_LIB_FAILURE = 				-32767,	//Operation Failure
 UFX_LIB_MORE_THAN_ONE_DEV		,		//More than one device detected library supports on device
 UFX_FRM_WRK_INIT_FAIL			,		//UFX Library Framework initialization failure, Generally occurs
 UFX_DRAM_NA					,		//Currently Framework holding wrong ODT Val, Re -init ODT Val									//for connection error or device not found

 UFX_HDWRE_INIT_FAIL 			,		//Able to communicate with UFX Device but Failing to initialize it
 UFX_DEV_COM_FAIL				,		//Fail to communicate with device, Check the connection and reintialize the lib  
 UFX_MEM_ALLOC_FAIL				,		//System is out of memory, can not proceed 
 UFX_INVALID_ARG				,		//Invalid arguement passed by the caller
 UFX_DRAM_VER_OVERALL_FAIL		,		//Failed to verify the contents
 UFX_DRAM_DATA_LINE_VER_FAIL	,		//Data line verification success
 UFX_DRAM_ADD_LINE_VER_FAIL		,		//Address line verification success
 UFX_EEPROM_VER_FAIL			,		//EEPROM Contents are not same as reference contents
 UFX_DRAM_VER_ISI_FAIL			,		//Inter-symbol interfrence test pass
 UFX_DRAM_WRONG_FRQ				,		//Currently Framework holding wrong Frequency, Re -init Frequency 
 UFX_DRAM_WRONG_ODT				,		//Currently Framework holding wrong ODT Val, Re -init ODT Val
 UFX_INVALID_EEPROM_ADD			,		//Invalid EEPROM Address specified by caller
 UFX_EEPROM_OUT_OF_BOUND		,		//Invalid EEPROM Address refrenced by caller
 UFX_INVALID_DRAM_ADD			,		//Invalid DRAM Address specified by caller
 UFX_DRAM_OUT_OF_BOUND			,		//Invalid DRAM Address refrenced by caller
 UFX_MONITOR_NOT_FOUND			,		//Failed to read EDID from Monitor
 UFX_EDID_PARSE_ERR				,		//Failes to parse EDID
 UFX_GE_INIT_FAILED				,
 UFX_FAILED_DRAW_OP				,
 UFX_INVALID_DRAW_REQ			,
 UFX_RESOLUTION_MISMATCH		,
 UFX_FILE_NOT_FOUND				,
 UFX_WRONG_FILE_FORMAT			,
 UFX_MODE_NOT_SUPPORTED			,
 UFX_FAILED_TO_READ_EDID		,

 UFX_LIB_SUCCESS =				0,		//Operation successfull
 UFX_EEPROM_VER_PASS			,		//EEPROM Contents are same as reference contents
 UFX_DRAM_VER_OVERALL_PASS		,		//Content verification success
 UFX_DRAM_DATA_LINE_VER_PASS	,		//Data line verification success
 UFX_DRAM_ADD_LINE_VER_PASS		,		//Address line verification success
 UFX_DRAM_VER_ISI_PASS			,		//Inter-symbol interfrence test pass
 }UFXLIB_RESULT;

/*
HDMI_SW_CFG_DATA structure is used by UFXHdmiPhyEnable API which enables HDMI port. Caller needs 
to initialize this structure before calling UFXHdmiPhyEnable with it as parameter.

Details of different members of structure and possible values

UINT8	bAudio:		Hdmi Audio
					Specify value 0, 1, 2, and 3 for 
					0 -> AUDIO_SPDIF
					1 -> AUDIO_I2S0,	
					2 -> AUDIO_I2S1, 
					3 -> AUDIO_AUTO,
INT8	bMCLK:		MCLK Input Mode
					1 -> MCLK is 128*Fs 
					2 -> MCLK is 256*Fs  
					3 -> MCLK is 384*Fs
					4 -> MCLK is 512*Fs
					5 -> MCLK is 768*Fs
					6 -> MCLK is 1024*Fs
					7 -> MCLK is 1152*Fs
					8 -> MCLK is 192*Fs
UINT8   bAudioFS:	Audio Sampling Frequency
					0 -> I2S_FS_AUTO
					1 -> I2S_FS_FORCE_48
					2 -> I2S_FS_FORCE_44
UINT8   bSuppressAVI:	Infro frame suppression
					0 -> Disable Suppression 
					1 -> Enable Suppression 
UINT8   bN_SVAL:	
					0 -> Default
					1 -> 44.1 or 48 kHz
DWORD	dwPortType: H;
					5 -> DC_PORT_HDMI_AV
					3 -> DC_PORT_HDMI_DVI
*/
typedef struct _HDMI_SW_CFG_DATA
{
	UINT8	bAudio;
	UINT8	bMCLK;
	UINT8   bAudioFS;
    UINT8   bSuppressAVI;
	UINT8   bN_SVAL;
	DWORD	dwPortType;
} HDMI_SW_CFG_DATA, *PHDMI_SW_CFG_DATA;

/* 
stMemoryParams is a structure used by functions to get and set the Frequency and ODT (on Die termination) value
The caller must user the below mentioned values for setting ODT and Frequency values 
DWORD dwClkFreq		    :  frequency
						  Specify value 1, 2, 3 and 4 for listed frequency
						  1 -> 300MHz,
						  2 -> 400MHz, 
						  3 -> 533MHz, 
						  4 -> 667MHz			
DWORD dwODTValue		:  ODT Value
						 Specify value 1, 2 and 3 for listed ODT Values
						 1 -> 75 ohm, 
						 2 -> 150 ohm, 
  						 3 -> ODT disabled.
By default UFX Device will be initialized to 300Mhz and ODT Disabled
*/
typedef struct{
	DWORD dwFrequency;		//Frequency value need to be set/get to/from Library
	DWORD dwODTValue;		//ODT value need to be set/get to/from Library
}stMemoryParams;

/* 
	Memory testing Functions returns stMemStatus  structure to inform success/failure. 
	If failure happens, dwDataLineNo, dwAddLineNo or dwMemoryLoc gets updated to represent
	the location of error.

	Memory can have any of the three problems
		- Shorting of Data Lines 	
		- Shorting Address Lines 
		- Memory Cell is not functioning properly 
	When Memory testing functions encounters the problem it populates  the 
	dwDataLineNo, dwAddLineNo or dwMemoryLoc to notify the failure location
	
	dwStatus represent actual status: Faliure Code or Success
*/
typedef struct{
	DWORD dwDataLineNo;		//Data Line having problem 
	DWORD dwAddLineNo;		//Address Line having problem
	DWORD dwMemoryLoc;		//Memory Location Having problem
	DWORD dwStatus;			//Status, Success code or Error Code 
}stMemStatus;

/* Supported Colors for drawing rectagles */
typedef enum {
	UFX_RED = 0,
	UFX_GREEN,
	UFX_BLUE,
	UFX_WHITE,
	UFX_BLACK,
}UFXLIB_RECT_COLOR;

#ifdef  ADVANCE_DISPLAY_API
typedef struct _DMT_MODE_P
{   // everything is in units of pixels, NOT CHAR's!!!
    DWORD dwHorPixels;
    DWORD dwVerPixels;
    DWORD dwRefresh;        // in Hz

    DWORD dwPixClk;         // in Hz, DMT shows floating-point MHz
    
    DWORD dwHtotal;
    DWORD dwHblankStart;
    DWORD dwHblankTime;
    DWORD dwHsyncStart;
    DWORD dwHsyncTime;

    DWORD dwVtotal;
    DWORD dwVblankStart;
    DWORD dwVblankTime;
    DWORD dwVsyncStart;
    DWORD dwVsyncTime;

    BOOLEAN fHsync;         // SYNC_POSITIVE or SYNC_NEGATIVE
    BOOLEAN fVsync;
    BYTE bFill[2];
} DMT_MODE_P, *PDMT_MODE_P;
#endif

typedef struct stRect{
	DWORD iXpos;
	DWORD iYpos;
	DWORD iWidth;
	DWORD iHeight;
}stRect_t;

typedef struct stResolution{
	DWORD dwHeight;
	DWORD dwWidth;
	DWORD dwFreuency;	
}stResolution_t;

/***Device and Library Framework Initialization/Deinitialization Function: Start***/

/* 
	Function Name:		UFXLibInit
	Description:		Application must call this function before performing any EEPROM or Memory 
	                    operation. 
	Blocks:				Yes
	Processing time:	56 MiliSeconds when device is conected						
	Input Arguments:	None
	Output:
	UFX_LIB_SUCCESS :		   Library initilization is successful
	UFX_LIB_MORE_THAN_ONE_DEV: Library supports only single UFX Device
	UFX_FRM_WRK_INIT_FAIL:		UFX Library Framework initialization failed
	UFX_HDWRE_INIT_FAIL:		UFX Device hardware initialization failed
*/
 extern "C" UFXLIB_RESULT UFXLIB_API UFXLibInit();

/* 
	Function Name:		UFXLibDeInit
	Description:		Applicaiton must call this function to release resources.
	Blocks:				Yes
	Processing time:	less than One Millisecond
	Input Arguments:	None
	Output:
	UFX_LIB_SUCCESS :	Always return success
*/
 extern "C" UFXLIB_RESULT UFXLIB_API UFXLibDeInit();

/**** Device and Library Framework Initialization/Deinitialization Function: End***/

/******************* EEPROM Read/Write Operation functions : Start ****************/

	/*-----------------------------------------
	Callin procedure:
		--- Call UFXLibInit();
		--- Do necessary procossing for EEPROM API like memory allocation, 
			size and start address initialization
		--- Call EEPROM Read/Write Operation functions
		--- Call UFXLibDeInit();
	-------------------------------------------*/

/* 
	Function Name:		UFXCalcEepromSize
	Description:		This function calculates the EEPROM  size
	Blocks:				Yes
	Processing time:	30 Milliseconds
	Input Arguments:	
	DWORD *pdwSize:		Address of DWORD type variable to hold the size
	Output:
	UFX_LIB_SUCCESS :	Size calculated successfully
	UFX_LIB_FAILURE:	Failed to calculate the size
	UFX_DEV_COM_FAIL:	Failed to communicate with device 	
	UFX_INVALID_ARG:	Invalid Argument supplied while calling 
*/
 extern "C" UFXLIB_RESULT UFXLIB_API UFXCalcEepromSize(DWORD *pdwSize );

/* 
	Function Name:		UFXLibWriteEEprom
	Description:		This function writes caller supplied data in EEPROM
	Blocks:				Yes
	Processing time:	3 Seconds for writing 512 Bytes						
	Input Arguments:	
	UCHAR pucBuf :		Buffer holding data 
	DWORD dStartAdd:	Memory offset
	DWORD Len:			Buffer Length 
	Output:
	UFX_LIB_SUCCESS :				EEPROM Programmed Successfully 
	UFX_DEV_COM_FAIL:				Failed to communicate with device 
	UFX_LIB_FAILURE:				Failed to Write EEPROM
	UFX_INVALID_ARG:				Invalid Arguement supplied while calling
	UFX_EEPROM_OUT_OF_BOUND			dStartAdd + dLen is reaching out of EEPROM Size
	UFX_INVALID_EEPROM_ADD			dStartAdd is not a valid address 
*/
 extern "C" UFXLIB_RESULT UFXLIB_API UFXLibWriteEEprom(UCHAR *pucBuf, DWORD dStartAdd, DWORD dLen);


/* 
	Function Name:			UFXLibReadEeprom
	Description:			This Function reads data from EEPROM  
	Blocks:					Yes
	Processing time:		250 Milliseconds for reading 512 Bytes
	Input Arguments:	
	UCHAR pucBuf :			Output buffer 
	DWORD dStartAdd:		Memory offset
	DWORD Len:				Buffer Length 
	Output:
	UFX_LIB_SUCCESS:				Successfully read EEPROM data
	UFX_LIB_FAILURE:				Failed to read data from EEPROM 
	UFX_DEV_COM_FAIL:				Failed to communicate with device	
	UFX_INVALID_ARG:				Invalid Arguement supplied while calling
	UFX_EEPROM_OUT_OF_BOUND			dStartAdd + dLen is reaching out of EEPROM Size
	UFX_INVALID_EEPROM_ADD			dStartAdd is not a valid address 
*/
 extern "C" UFXLIB_RESULT UFXLIB_API UFXLibReadEeprom(UCHAR *pucBuf, DWORD dStartAdd, DWORD dLen);

/* 
	Function Name:			UFXLibEraseEeprom
	Description:			This function erases EEPROM content 
	Blocks:					Yes
	Processing time:		5 Milliseconds
	Input Arguments:	
	NONE
	Output:
	UFX_LIB_SUCCESS:		EEPROM Erase successful
	UFX_LIB_FAILURE:		EEPROM Erase failed
	UFX_DEV_COM_FAIL:		Failed to communicate with device
*/
 extern "C" UFXLIB_RESULT UFXLIB_API UFXLibEraseEeprom();
/******************* EEPROM Read/Write Operation functions : End ****************/


/****************Get/Set functions for Memory Size, ODT and Frequency: Start *********/
/* 
	Function Name:		UFXSetMemSize
	Description:		Application optionatlly can call this function to initialize memory size.
						Default memory size is 32 MB. 
	Blocks:				Yes
	Processing time:	less than One Millisecond
	Input Arguments:	Memory size
	Output:
	UFX_LIB_SUCCESS :   Successfully initialized memory size to framework
	UFX_LIB_FAILURE :	Failed initialize memory size to framework
	UFX_INVALID_ARG:	Invalid Argument  supplied while calling 
*/
 extern "C" UFXLIB_RESULT UFXLIB_API UFXSetMemSize(DWORD dwSize);

/* 
	Function Name:		UFXSetODTnFrequency
	Description:		Application optionally can call this function to set ODT and Fequency. 
						Default Setting : 
						Frequency 	-> 300MHz 
						ODT			-> ODT disabled
	Blocks:				Yes
	Processing time:	30 MiliSeconds 
	Input Arguments:	stMemoryParams
	Output:
	UFX_LIB_SUCCESS :		  Frequency and ODT value initialization  is successful
	UFX_FRM_WRK_INIT_FAIL:	  UFX Library Framework initialization failed
	UFX_HDWRE_INIT_FAIL:	  UFX Device hardware initialization failed
	UFX_DEV_COM_FAIL:		  Failed to communicate with device 
	UFX_INVALID_ARG:		  Invalid Argument supplied while calling 
*/
 extern "C" UFXLIB_RESULT UFXLIB_API UFXSetODTnFrequency(stMemoryParams stMemObj );

/* 
	Function Name:		UFXGetMemSize
	Description:		This functions returns the DRAM memory size.
	Blocks:				Yes
	Processing time:	less than One Millisecond
	Input Arguments:	None
	Output:				DWORD	Memory Size		
*/
 extern "C" DWORD UFXLIB_API UFXGetMemSize();

/* 
	Function Name:		UFXGetODTnFrequency
	Description:		This function returns the current settings for Frequency and ODT
	Blocks:				Yes
	Processing time:	less than One Millisecond
	UFXLibEraseEeprom Arguments:	
	stMemoryParams		*pstMemObj
	Output:
	UFX_LIB_SUCCESS :	Library initialization is successful
	UFX_INVALID_ARG:	Invalid Argument supplied while calling 
*/
 extern "C" UFXLIB_RESULT UFXLIB_API UFXGetODTnFrequency(stMemoryParams *pstMemObj );

/**************Get/Set functions for Memory Size, ODT and Frequency: End **********/

/***************** DRAM Read/Write and Verification functions : Starts ************/

	/*-----------------------------------------
	Callin procedure:
		--- Call UFXLibInit();
		--- Do necessary processing for DRAM API like memory allocation, 
			size and start address initialization
		--- Call EEPROM Read/Write Operation functions
		--- Call UFXLibDeInit();
	-------------------------------------------*/

/* 
	Function Name:		UFXMemoryDataLinesTest
	Description:		This function verifies DRAM data lines. Here is algorithm
							1. Verify Address line
							2. Generate bit pattern qwPattern = 00000 0000 0000 00001
							3. For I = 0 to 31									
							4. Write qwPattern arbitary at memory location
							5. Read back the previously written memory location and compare with qwPattern
							6. qwPattern and read value should be same
							7. If same increase I to I+1  and change qwPattern to qwPattern << 1 jump to step 3 else return fail 
							8. Repeate Step 3 to step 7 four time

	Blocks:				Yes
	Processing time:	400 Milliseconds
	Input Arguments:	None	
	Output:				Status structure type stMemStatus	
	stMemStatus.dwAddLineNo and	stMemStatus.dwMemoryLoc are not applicable for this function
	stMemStatus.dwDataLineNo: UFX_DRAM_NA			//Other than data line problem
							  Data Line(0 - 31)		//Data line having problem
	stMemStatus.dwStatus:	Depending on operation status below mentioned values
		UFX_DRAM_DATA_LINE_VER_PASS:	Successfully verified Data lines
		UFX_DRAM_DATA_LINE_VER_FAIL:	Failed to verify Data lines		
		UFX_DRAM_ADD_LINE_VER_FAIL:		There is problem with address lines	
		UFX_HDWRE_INIT_FAIL:			Failed to initialization UFX Hardware
		UFX_DEV_COM_FAIL:				Failed to communicate with device	
		UFX_INVALID_ARG:				Invalid Arguments supplied by caller
*/
extern "C" stMemStatus UFXLIB_API UFXMemoryDataLinesTest();

/* 
	Function Name:		UFXMemoryAddressLinesTest
	Description:		This function verifies DRAM address lines. The algorithm is following
						1. Generate pattern qwPattern=0xA523456789ABCDEFUL
						2. For I=3 to Address lines
						3. Generate the possible addresses which might result of shorting of adjacent address lines
							dwOriginalAdd		= 1UL<<I;	//Original address				
							dwShortPosLeftAdd	= dwOriginalAdd | 1UL<<(i+1); //Address due to short left address line also become high 
							dwShortPosRightAdd  = dwOriginalAdd | 1UL<<(i-1); //Address due to short right address line also become high
							address = 0 //Is always possiblity as shorting might result to zero of both shorted lines

						4. Write 0 to
								address = 0;
								dwShortPosLeftAdd;
								dwShortPosRightAdd;								
						5. Write qwPattern to dwOriginalAdd
						6. Read pattern at address = 0, dwShortPosLeftAdd and dwShortPosRightAdd. Check if it is zero
						7. If No return Error
						8. Read pattern from dwOriginalAdd and compare with qwPattern. If they are not same return Error
						9. Increase I by 1 and Jump to step 2
 
	Blocks:				Yes
	Processing time:	250 Milliseconds
	Input Arguments:	None
	Output:
	Output:				Status structure of type stMemStatus
	stMemStatus.dwDataLineNo and	stMemStatus.dwMemoryLoc are not applicable for this function
	stMemStatus.dwAddLineNo : UFX_DRAM_NA				//Problem other than Address line 
							  Address Line(0 - 31)		//Address line having problem
	UFX_DRAM_ADD_LINE_VER_PASS:		Successfully verified address lines
	UFX_DRAM_ADD_LINE_VER_FAIL:		Failed to verify Address lines		
	UFX_HDWRE_INIT_FAIL:			Failed to initialization UFX Hardware
	UFX_DEV_COM_FAIL:				Failed to communicate with device	
	UFX_INVALID_ARG:				Invalid Arguments supplied by caller
*/
extern "C" stMemStatus UFXLIB_API UFXMemoryAddressLinesTest();

/* 
	Function Name:		UFXVerifyFullDRAM
	Description:		This function verifies full DRAM.  The algorithm is following.,
						- Verify Address line
						- Verify data lines						
						- Verify each memory cell by writing 0x0123456789ABCDEFUL in entire RAM area using BULK-OUT Transfer 
						  and read back data using Control transfer in chunk of 8-bytes and compare with data written.						  

						  This process takes 1 Hour and 20 Minutes for 32MB DRAM as it verifies each cell, For quicker operation
						  try Address and Data Line verification APIs
	Blocks:				Yes
	Processing time:	1Hour 20 Minutes
	Input Arguments:	NONE	
	
	Output:				Status structure of type stMemStatus
	stMemStatus.dwAddLineNo:  UFX_DRAM_NA			//Not applicable for address lines
							  0 - 31				//Address line having problem
	stMemStatus.dwDataLineNo:  UFX_DRAM_NA			//Not applicable for data lines
							  0 - 31				//Data line having problem
	stMemStatus.dwMemoryLoc:  UFX_DRAM_NA			//Not applicable for Memory
							  0 - Memory size-1		//Memory Location having problem

	stMemStatus.dwStatus:	Can be any possible value mentioned below depending on operation status
		UFX_DRAM_VER_OVERALL_PASS:		Overall DRAM verified successfully
		UFX_DRAM_VER_OVERALL_FAIL:		Overall DRAM verification failed ( Occurs when failed to verify the content of each Memory Cell)
		UFX_HDWRE_INIT_FAIL:			Failed to initialization UFX Hardware 
		UFX_DEV_COM_FAIL:				Failed to communicate with device 	
		UFX_DRAM_DATA_LINE_VER_FAIL:	There is problem with data lines
		UFX_DRAM_ADD_LINE_VER_PASS:		There is problem with address lines			
		UFX_INVALID_ARG:				Invalid Arguement supplied while calling 
*/
extern "C" stMemStatus UFXLIB_API UFXVerifyFullDRAM();

/* 
	Function Name:		UFXDRAMWrite
	Description:		This function writes caller specified data in DRAM
						Caller can specify transfer type BULK/Control. 
	Blocks:				Yes
	Processing time:	less than One Millisecond for 1024 bytes
	Input Arguments:	
	UCHAR pucBuf :			Buffer holding data
	DWORD dStartAdd:		Starting address in DRRAM 
	DWORD Len:				Buffer Length 
	UCHAR ucTransferType:	USB Transfer Type BULK/CONTROL
							0 -> BULK
							1 -> Control
	Output:	
	UFX_LIB_SUCCESS:	Data written successfully to DRAM
	UFX_LIB_FAILURE:	Failed to write data in DRAM 
	UFX_DEV_COM_FAIL:	Failed to communicate with device 	
	UFX_INVALID_ARG:	Invalid Arguments supplied by caller
	UFX_DRAM_OUT_OF_BOUND: Invalid DRAM Address referenced  
	UFX_INVALID_DRAM_ADD:  Invalid DRAM Address 
*/
extern "C" UFXLIB_RESULT UFXLIB_API UFXDRAMWrite(UCHAR *pucBuf, DWORD dStartAdd, DWORD dwLen, UCHAR ucTransferType );


/* 
	Function Name:		UFXDRAMRead
	Description:		This function reads data from DRAM  
	Blocks:				Yes
	Processing time:	115 Milliseconds for reading 1024 Bytes
	Input Arguments:	
	UCHAR pucBuf :		Buffer to store data read from DRAM
	DWORD dStartAdd:	Starting address 
	DWORD Len:			Buffer Length 	
	Output:
	UFX_LIB_SUCCESS:	Data read successfully
	UFX_LIB_FAILURE:	Failed to read data
	UFX_DEV_COM_FAIL:	Failed to communicate with device 
	UFX_INVALID_ARG:	Invalid Arguments supplied by caller
	UFX_DRAM_OUT_OF_BOUND: Invalid DRAM Address referenced  
	UFX_INVALID_DRAM_ADD:  Invalid DRAM Address 
*/
extern "C" UFXLIB_RESULT UFXLIB_API UFXDRAMRead(UCHAR *pucBuf, DWORD dStartAdd, DWORD dwLen );
/**************** DRAM Read/Write and Verification functions : End **************/


/* 
	Function Name:		UFXPreferedResolution
	Description:		This function gets the prefered/Native resolution of Monitor
	Input Arguments:	
	stResolution_t *pstReso:	Pointer to structre used for storing resolution details
	Output:
	UFX_LIB_SUCCESS:		Data read successfully
	UFX_INVALID_ARG:		Invalid Arguments supplied by caller
	UFX_EDID_PARSE_ERR:		Failed to get EDID from Monitor or parse EDID		

	usage:
	-----------------------------------------
	Callin procedure:
		--- Call UFXLibInit();
		--- create stResolution_t structure and call UFXPreferedResolution
			with stResolution_t as parameter
		--- Call UFXLibDeInit();
	-------------------------------------------
*/
extern "C" UFXLIB_RESULT UFXLIB_API UFXPreferedResolution(stResolution_t *);

/* 
	Function Name:		UFXDrawRect
	Description:		This function draws a rectangle on display with caller specified parameters  
	Input Arguments:	
	UFXLIB_RECT_COLOR eColor:		Buffer to store data read from DRAM
									0 -> Red
									1 -> Green
									2 -> Blue
									3 -> White
									4 -> Black

	stRect_t Rect:					Structure for specifying X-Pos & Y-Pos and Width & Height  	 
	Output:
	UFX_LIB_SUCCESS:		Data read successfully
	UFX_LIB_FAILURE:		Failed to read data
	UFX_DEV_COM_FAIL:		Failed to communicate with device 
	UFX_INVALID_ARG:		Invalid Arguments supplied by caller
	UFX_INVALID_DRAW_REQ:	One or more parameters are wrong in stRect_t
	UFX_GE_INIT_FAILED:		Failed to initialize Graphics Engine

	usage:
	-----------------------------------------
	Callin procedure:
		--- Call UFXLibInit();
		--- Call UFXInitGE to Initialize Graphics Engine with desired Resolution and referesh rate
			Ex:
			stResolution_t stTemp = {0};
			stTemp.dwWidth = 1280;
			stTemp.dwHeight = 1024;
			stTemp.dwFreuency = 60;
			UFXInitGE(stTemp);
		--- Create stRect_t structure with rectangle dimensions and specify color in eColor. Dimensions 
			should be in accordance with resolution set using UFXInitGE(stTemp);
		--- Call UFXDrawRect
		--- Call UFXLibDeInit();
	-------------------------------------------
*/
extern "C" UFXLIB_RESULT UFXLIB_API UFXDrawRect(UFXLIB_RECT_COLOR eColor, stRect_t Rect);

/* 
	Function Name:		UFXDrawPic
	Description:		This function displays caller specified picture  
	Input Arguments:	
	UCHAR pucBuf :		File path
	Output:
	UFX_LIB_SUCCESS:		Data read successfully
	UFX_LIB_FAILURE:		Failed to read data
	UFX_DEV_COM_FAIL:		Failed to communicate with device 
	UFX_INVALID_ARG:		Invalid Arguments supplied by caller
	UFX_EDID_PARSE_ERR:		Failed to get EDID from Monitor or parse EDID
	UFX_RESOLUTION_MISMATCH: Specified file resolution do not match with native monitor resolution 
	UFX_FILE_NOT_FOUND:		Wrong file path
	UFX_WRONG_FILE_FORMAT:	Image format is other than bmp format

	usage:
	-----------------------------------------
	Callin procedure:
		--- Call UFXLibInit();
		--- Call UFXInitGE to initialize Graphics Engine(GE) with desired Resolution and referesh rate
			Ex:
			stResolution_t stTemp = {0};
			stTemp.dwWidth = 1280;
			stTemp.dwHeight = 1024;
			stTemp.dwFreuency = 60;
			UFXInitGE(stTemp);
		--- Specify correct bmp file path and call UFXDrawPic
			Note: File should be in BMP format and resoultion set using UFXInitGE should have exact resoultion as 
			bmp file
		--- Call UFXLibDeInit();
	-------------------------------------------
*/
extern "C" UFXLIB_RESULT UFXLIB_API UFXDrawPic(UCHAR *ucPath);

/* 
	Function Name:		UFXInitGE
	Description:		This function initializes the Graphics Engine(GE) at desired and supported resolution by monitor before calling 
						graphics operations Draw Image or rectangle, GE must be initialized properly
							
	Input Arguments:	
	stResolution_t		stRes desired resolution
	Output:
	UFX_LIB_SUCCESS:		Data read successfully
	UFX_MODE_NOT_SUPPORTED:	Mode specified by caller in argument(stReso) is not supported
	UFX_HDWRE_INIT_FAIL:	UFX Device hardware initialization failed
	UFX_GE_INIT_FAILED:		Failed to initialize Graphics Engine 

	usage:
	-----------------------------------------
	Callin procedure:
		--- Call UFXLibInit();
		--- Call UFXInitGE to Initialize GE with desired Resolution and referesh rate
			Ex:
			stResolution_t stTemp = {0};
			stTemp.dwWidth = 1280;
			stTemp.dwHeight = 1024;
			stTemp.dwFreuency = 60;
			UFXInitGE(stTemp);
		--- Specify correct bmp file path and call UFXDrawPic
			Note: File should be in BMP format and resoultion set using UFXInitGE should have exact resoultion as 
			bmp file
		--- Call UFXLibDeInit();
	-------------------------------------------
*/
extern "C" UFXLIB_RESULT UFXLIB_API UFXInitGE(stResolution_t stRes );


/* 
	Function Name:		UFXHdmiPhyEnable
	Description:		This function enables the HDMI Interface for displaying images 
						and playing sound 
	Input Arguments:	
	HDMI_SW_CFG_DATA	Structure specifying different paramete 
						refer HDMI_SW_CFG_DATA structure details
	Output:
	UFX_LIB_SUCCESS:	HDMI enabled successfully
	UFX_LIB_FAILURE:	Failed to initialize HDMI
	
	usage:
	-----------------------------------------
	Callin procedure:
		--- Call UFXLibInit();
		--- Create structure HDMI_SW_CFG_DATA object and populate it
			as per requirement refer structure description
		--- Call UFXHdmiPhyEnable to enable HDMI
		--- Call UFXLibDeInit();
	-------------------------------------------
*/
extern "C" UFXLIB_RESULT UFXLIB_API UFXHdmiPhyEnable(HDMI_SW_CFG_DATA *pHDMI_SW_CFG_DATAObj);


/* 
	Function Name:		UFXHdmiPhyDisable
	Description:		This function disables the HDMI Interface 

	Input Arguments:	
	None
	Output:
	UFX_LIB_SUCCESS:	HDMI disabled successfully
	UFX_LIB_FAILURE:	Failed to disable HDMI
	
	usage:
	-----------------------------------------
	Callin procedure:
		--- Call UFXLibInit();
		--- Call UFXHdmiPhyDisable to disable HDMI
		--- Call UFXLibDeInit();
	-------------------------------------------
*/
extern "C" UFXLIB_RESULT UFXLIB_API UFXHdmiPhyDisable();


/* 
	Function Name:		UFXResetDevice
	Description:		This function resets the device.

	Note: A reset will result in the contents of the EEPROM being reloaded. 
		  While the reset sequence is in progress, the USB PHY will be disconnected. 
          After the device has been reinitialized, it will take the PHY out of the 
          disconnect state and be visible to the Host.
		  
		  Caller off this API has to reinitialize the values in desired registers in
		  order operate again on the device.

	Input Arguments:	
	None
	Output:
	UFX_LIB_SUCCESS:	Successfully reset device
	UFX_LIB_FAILURE:	Failed to reset device
	
	usage:
	-----------------------------------------
	Callin procedure:
		--- Call UFXLibInit();
		--- Call UFXResetDevice to reset device
		--- Call UFXLibDeInit();
	-------------------------------------------
*/
extern "C" UFXLIB_RESULT UFXLIB_API UFXResetDevice();